"""
    EMIL BillingService

    The EMIL BillingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.billing
from eis.billing.api.invoices_api import InvoicesApi  # noqa: E501


class TestInvoicesApi(unittest.TestCase):
    """InvoicesApi unit test stubs"""

    def setUp(self):
        self.api = InvoicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_invoice(self):
        """Test case for create_invoice

        Create the invoice  # noqa: E501
        """
        pass

    def test_get_invoice(self):
        """Test case for get_invoice

        Retrieve the invoice  # noqa: E501
        """
        pass

    def test_list_invoices(self):
        """Test case for list_invoices

        List invoices  # noqa: E501
        """
        pass

    def test_list_policies_billing_dates(self):
        """Test case for list_policies_billing_dates

        List policies billing dates  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
