"""
    EMIL BillingService

    The EMIL BillingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.billing
from eis.billing.api.draft_invoice_api import DraftInvoiceApi  # noqa: E501


class TestDraftInvoiceApi(unittest.TestCase):
    """DraftInvoiceApi unit test stubs"""

    def setUp(self):
        self.api = DraftInvoiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_draft_invoice(self):
        """Test case for create_draft_invoice

        """
        pass

    def test_delete_all_draft_invoices(self):
        """Test case for delete_all_draft_invoices

        """
        pass

    def test_delete_draft_invoice(self):
        """Test case for delete_draft_invoice

        """
        pass


if __name__ == '__main__':
    unittest.main()
